     6
     7
     8
     9
    10
    11
    12
    13
    14
    15
    16
    17
    Line 6
    Line 7
    Line 8
    Line 9
    Line 10
    Line 11
    Line 12
    Line 13
    Line 14
    Line 15
    Line 16
    Line 17

    46
    47
    48
    49
    50
    51
    52
    53
    54
    55
    56
    57
    58
    59
    60
    61
    Line 46
    Line 47
    Line 48
    Line 49
    Line 50
    Line 51
    Line 52
    Line 53
    Line 54
    Line 55
    Line 56
    Line 57
    Line 58
    Line 59
    Line 60
    Line 61